Calculate sensitivity index and bias based on signal detection theory. The correction for extreme proportions of zero and one is the "log-linear" rule recommended by Hautus (1995).
Arguments
- data
Raw data of class
data.frame.- type_signal
The type of signal stimuli. It should be one of the values in the
name_typecolumn ofdata.- ...
For future extensions. Should be empty.
- by
The column name(s) in
dataused to be grouped by. If set toNULL, all data will be treated as from one subject.- name_acc
The column name of the
datainput whose values are user's correctness, in which is anumericvector so coded that 1 means scoring correct, 0 means scoring incorrect, and that -1 means no response is made.- name_type
The column name of the
datainput whose values are the stimuli types. Based ontype_signal, the other types of stimuli will be treated as non-signal stimuli.
Value
A tibble contains sensitivity index and bias (and other temporary measures).